from setuptools import setup

setup(
    name='lyytkwidget',
    version='1.6',
    author='lyy',
    author_email='',
    description='yyjdgui for lyy',
    #packages=find_packages(),
    license="MIT",
    install_requires=[
        "win10toast ",

    ],
)